pilas.motores.motor_qt.CanvasWidgetSugar

Package pilas :: Package motores :: Module motor_qt :: Class CanvasWidgetSugar |
[hide private]
[frames] | no frames]

# Class CanvasWidgetSugar

source code

    PyQt4.QtGui.QWidget --+
                          |
               CanvasWidget --+
                              |
                             CanvasWidgetSugar

Instance Methods | [hide private]
_iniciar_aplicacion(self) | source code
ejecutar_bucle_principal(self, mundo, ignorar_errores) | source code
Inherited from `CanvasWidget`: `__init__`, `alternar_pantalla_completa`, `alternar_pausa`, `avanzar_un_solo_cuadro_de_animacion`, `esta_en_pantalla_completa`, `keyPressEvent`, `keyReleaseEvent`, `mouseMoveEvent`, `mousePressEvent`, `mouseReleaseEvent`, `paintEvent`, `pantalla_completa`, `pantalla_modo_ventana`, `resize_to`, `timerEvent`, `wheelEvent` Inherited from `CanvasWidget` (private): `_actualizar_escena`, `_actualizar_eventos_y_actores`, `_obtener_codigo_de_tecla_normalizado`, `_realizar_actualizacion_logica`